@@ -38,7 +38,7 @@ def purge_logs():
     """
     os.makedirs(logdir, exist_ok=True)
     for f in [f for f in os.listdir(logdir)]:
-        os.remove(f"{logdir}{f}")
+        os.remove(f"{logdir}/{f}")
 
 class TestRoll():
     def __init__(self, override=(None, None)):
